@@ -1,9 +1,9 @@
 package Dist::Zilla::Plugin::Sah::Schemas;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-20'; # DATE
+our $DATE = '2021-07-29'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.023'; # VERSION
+our $VERSION = '0.024'; # VERSION
 
 use 5.010001;
 use strict;
@@ -134,7 +134,6 @@ sub munge_files {
                     $res = Data::Sah::Resolve::resolve_schema(
                         {
                             schema_is_normalized => 1,
-                            return_intermediates => 1,
                         },
                         $nsubsch);
                 };
@@ -142,7 +141,7 @@ sub munge_files {
                     $self->log(["Can't resolve schema (%s), skipped collecting base schemas for %s", $@, $pkg]);
                     last COLLECT_BASE_SCHEMAS;
                 }
-                my $intermediates = $res->[2];
+                my $intermediates = $res->[2]{intermediates};
                 for my $i (0..$#{$intermediates}-1) {
                     my $mod = "Sah::Schema::$intermediates->[$i]";
                     $self->{_used_schema_modules}{$mod}++;
@@ -178,7 +177,7 @@ sub munge_files {
             my $rschema;
             eval {
                 $rschema = Data::Sah::Resolve::resolve_schema(
-                    {return_intermediates => 1},
+                    {},
                     $sch,
                 );
             };
@@ -317,7 +316,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.023 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2021-07-20.
+This document describes version 0.024 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2021-07-29.
 
 =head1 SYNOPSIS
 
